Getting Help With PyDM
======================

If you have questions of comments in general about PyDM we want to know.

You can choose between the channels open for communication the one that best fit you:

- `Chat channel using Gitter <https://gitter.im/pydm/General>`_ (Public)
- `Stanford & SLAC Slack channel <https://slac.slack.com/messages/C6B8GRCPQ>`_ (Limited for users with a Stanford Account)
- `PyDM Mailing List <https://listserv.slac.stanford.edu/cgi-bin/wa?SUBED1=PYDM-USERS>`_ (Limited for SLAC users for now)

or you can `file a bug <https://github.com/slaclab/pydm/issues>`_ and let us know where our documentation could be improved.
